@@ -71,16 +71,18 @@ func (f *httpMultiFlagList) Set(value string) error {
 
 // Usage to a writer.
 func usage(w io.Writer, msgs ...interface{}) {
-	_, _ = fmt.Fprintf(w, "Φορτίο %s usage:\n\t%s command [flags] target\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n",
+	_, _ = fmt.Fprintf(w, "Φορτίο %s usage:\n\t%s command [flags] target\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n",
 		version.Short(),
 		os.Args[0],
 		"where command is one of: load (load testing), server (starts ui, rest api,",
-		" http-echo, redirect, proxies, tcp-echo and grpc ping servers), tcp-echo (only",
-		" the tcp-echo server), report (report only UI server), redirect (only the",
-		" redirect server), proxies (only the -M and -P configured proxies), grpcping",
-		" (grpc client), or curl (single URL debug), or nc (single tcp or udp://",
-		" connection), or version (prints the full version and build details).",
-		"where target is a url (http load tests) or host:port (grpc health test).")
+		" http-echo, redirect, proxies, tcp-echo, udp-echo and grpc ping servers), ",
+		" tcp-echo (only the tcp-echo server), udp-echo (only udp-echo server),",
+		" report (report only UI server), redirect (only the redirect server),",
+		" proxies (only the -M and -P configured proxies), grpcping (grpc client),",
+		" or curl (single URL debug), or nc (single tcp or udp:// connection),",
+		" or version (prints the full version and build details).",
+		"where target is a url (http load tests) or host:port (grpc health test),",
+		" or tcp://host:port (tcp load test), or udp://host:port (udp load test).")
 	bincommon.FlagsUsage(w, msgs...)
 }
 
@@ -183,7 +185,16 @@ var (
 	calcQPS = flag.Bool("calc-qps", false, "Calculate the qps based on number of requests (-n) and duration (-t)")
 )
 
-//nolint:funlen,gocyclo // well yes it's fairly big and lotsa ifs.
+// serverArgCheck always returns true after checking arguments length.
+// so it can be used with isServer = serverArgCheck() below.
+func serverArgCheck() bool {
+	if len(flag.Args()) != 0 {
+		usageErr("Error: too many arguments (typo in a flag?)")
+	}
+	return true
+}
+
+//nolint:funlen // well yes it's fairly long
 func main() {
 	flag.Var(&proxiesFlags, "P",
 		"Tcp proxies to run, e.g -P \"localport1 dest_host1:dest_port1\" -P \"[::1]:0 www.google.com:443\" ...")
@@ -229,10 +240,10 @@ func main() {
 	case "load":
 		fortioLoad(*curlFlag, percList)
 	case "redirect":
-		isServer = true
+		isServer = serverArgCheck()
 		fhttp.RedirectToHTTPS(*redirectFlag)
 	case "report":
-		isServer = true
+		isServer = serverArgCheck()
 		if *redirectFlag != disabled {
 			fhttp.RedirectToHTTPS(*redirectFlag)
 		}
@@ -240,23 +251,20 @@ func main() {
 			os.Exit(1) // error already logged
 		}
 	case "tcp-echo":
-		isServer = true
+		isServer = serverArgCheck()
 		fnet.TCPEchoServer("tcp-echo", *tcpPortFlag)
 		startProxies()
 	case "udp-echo":
-		isServer = true
+		isServer = serverArgCheck()
 		fnet.UDPEchoServer("udp-echo", *udpPortFlag, *udpAsyncFlag)
 		startProxies()
 	case "proxies":
-		if len(flag.Args()) != 0 {
-			usageErr("Error: fortio proxies command only takes -P / -M flags")
-		}
-		isServer = true
+		isServer = serverArgCheck()
 		if startProxies() == 0 {
 			usageErr("Error: fortio proxies command needs at least one -P / -M flag")
 		}
 	case "server":
-		isServer = true
+		isServer = serverArgCheck()
 		if *tcpPortFlag != disabled {
 			fnet.TCPEchoServer("tcp-echo", *tcpPortFlag)
 		}
